<?php

/**
 * Copyright 2019 IQRF Tech s.r.o.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
declare(strict_types = 1);

namespace Iqrf\Repository\Entities;

use JsonSerializable;

/**
 * Company entity
 */
final class Company implements JsonSerializable {

	/**
	 * @var int Company ID
	 */
	private $id;

	/**
	 * @var string Company name
	 */
	private $name;

	/**
	 * @var string Company homepage
	 */
	private $homepage;

	/**
	 * Constructor
	 * @param int $id Company ID
	 * @param string $name Company name
	 * @param string $homepage Company homepage
	 */
	public function __construct(int $id, string $name, string $homepage) {
		$this->id = $id;
		$this->name = $name;
		$this->homepage = $homepage;
	}

	/**
	 * Creates a new company entity from an array
	 * @param array<string, int|string> $data JSON data in an array
	 * @return Company Created company entity
	 */
	public static function fromArray(array $data): self {
		return new self($data['companyID'], $data['name'], $data['homePage']);
	}

	/**
	 * Returns the company ID
	 * @return int Company ID
	 */
	public function getId(): int {
		return $this->id;
	}

	/**
	 * Returns the company name
	 * @return string Company name
	 */
	public function getName(): string {
		return $this->name;
	}

	/**
	 * Returns the company homepage
	 * @return string Company homepage
	 */
	public function getHomepage(): string {
		return $this->homepage;
	}

	/**
	 * Serializes the Company entity into JSON
	 * @return array<string, int|string> JSON serialized Company entity
	 */
	public function jsonSerialize(): array {
		return [
			'id' => $this->id,
			'name' => $this->name,
			'homepage' => $this->homepage,
		];
	}

}
